/**
 * Author: Niels Tsang
 * Date: 2011/07/13
 * 
 * SPOJ 100 - Tower of Babylon (Problem code: BABTWR)
 * Problem Type: LIS (Longest Increasing Subsequence)
 * http://www.spoj.pl/problems/BABTWR/
 * 
 * Let OPT[i] be the highest height of blocks[1..i] that ends exactly at blocks[i]
 * OPT[i] = max( OPT[k] + blocks[i] where k < i and blocks[k] < blocks[i] );
 * for i = 1..n
 *   OPT[i] = blocks[i];
 *   for k = 1..(i-1)
 *     if a[k] < a[i]
 *       OPT[i] = max( OPT[i], OPT[k] + blocks[i] );
 * cout << max( OPT[j] where j = 1..n );
 * Time Complexity: O(n^2)
 * but O(nlogn) time is feasible
 * 
 * Analysis of sample input:
 * (sort by z in asc order, and then by x in desc order)
 *  y  x  z
 * 83 27 33 -> 83
 * 59 31 41 -> 59
 * 58 26 53
 * 26 53 58
 * 53 26 58
 * 31 41 59 -> 31
 * 41 31 59
 * 84 62 64 -> 84
 * 27 33 83
 * 33 27 83
 * 62 64 84 -> 62
 * 64 62 84
 * 97 23 93
 * 23 93 97 -> 23
 * 93 23 97
 * ---------------
 *       sum = 342
 */

#include <algorithm>
#include <iostream>
using namespace std;

struct Block {
    int y, x, z;
};

bool operator < ( const Block& a, const Block& b ) {
    if( a.z != b.z ) {
        return( a.z < b.z );
    }
    else {
        return( a.x > b.x );
    }
}

Block blocks[91];
int OPT[91];

int main() {
    int n;
    while( cin >> n ) {
        if( n == 0 ) { break; }
        for( int i=0; i<n; ++i ) {
            int y, x, z;
            cin >> y >> x >> z;
            blocks[i*3+0].y = y; blocks[i*3+0].x = min(x,z); blocks[i*3+0].z = max(x,z);
            blocks[i*3+1].y = x; blocks[i*3+1].x = min(y,z); blocks[i*3+1].z = max(y,z);
            blocks[i*3+2].y = z; blocks[i*3+2].x = min(x,y); blocks[i*3+2].z = max(x,y);
        }
        sort( blocks, blocks+(n*3) );
        for( int i=0; i<(n*3); ++i ) {
            OPT[i] = blocks[i].y;
            for( int k=0; k<i; ++k ) {
                if( blocks[k].x < blocks[i].x ) {
                    OPT[i] = max( OPT[i], OPT[k] + blocks[i].y );
                }
            }
        }
        int highestPossibleTowerHeight = 0;
        for( int i=0; i<(n*3); ++i ) {
            if( highestPossibleTowerHeight < OPT[i] ) {
                highestPossibleTowerHeight = OPT[i];
            }
        }
        cout << highestPossibleTowerHeight << endl;
    }
    return( 0 );
}
